@@ -9,9 +9,7 @@ from .responses import UJSONResponse
 from .utils import logger as LOG
 
 
-async def http_exception_handler(
-    request: Request, exc: StarletteHTTPException
-) -> UJSONResponse:
+async def http_exception_handler(request: Request, exc: StarletteHTTPException) -> UJSONResponse:
     """
     Handles StarletteHTTPException, translating it into flat dict error data:
         * code - unique code of the error in the system
@@ -31,9 +29,7 @@ async def http_exception_handler(
     return UJSONResponse(data, status_code=exc.status_code)
 
 
-async def validation_exception_handler(
-    request: Request, exc: RequestValidationError
-) -> UJSONResponse:
+async def validation_exception_handler(request: Request, exc: RequestValidationError) -> UJSONResponse:
     """
     Handles ValidationError, translating it into flat dict error data:
         * code - unique code of the error in the system
@@ -67,9 +63,7 @@ async def validation_exception_handler(
     return UJSONResponse(data, status_code=status_code)
 
 
-async def pydantic_validation_exception_handler(
-    request: Request, exc: ValidationError
-) -> UJSONResponse:
+async def pydantic_validation_exception_handler(request: Request, exc: ValidationError) -> UJSONResponse:
     """
     Handles ValidationError, translating it into flat dict error data:
         * code - unique code of the error in the system
@@ -97,8 +91,8 @@ async def pydantic_validation_exception_handler(
 
     data = {
         "code": "Server Validation Error",
-        "detail": f"A domain object has failed validation this is likely due to changes in the model or "
-        + f"database structure. Creating a new dataset may solve the issue.",
+        "detail": "A domain object has failed validation this is likely due to changes in the model or "
+        + "database structure. Creating a new dataset may solve the issue.",
         "error": str(exc),
     }
     return UJSONResponse(data, status_code=500)
@@ -107,9 +101,7 @@ async def pydantic_validation_exception_handler(
 async def assert_exception(request: Request, exc: AssertionError) -> UJSONResponse:
     LOG.warning(f"Assert exception caught: {str(exc)}")
     data = {"code": "Assertion Error", "detail": str(exc)}
-    return UJSONResponse(
-        data, status_code=400, headers={"Access-Control-Allow-Origin": "*"}
-    )
+    return UJSONResponse(data, status_code=400, headers={"Access-Control-Allow-Origin": "*"})
 
 
 async def default_exception(request: Request, exc: Exception) -> UJSONResponse:
@@ -119,9 +111,7 @@ async def default_exception(request: Request, exc: Exception) -> UJSONResponse:
         "detail": str(exc),
         "trace": traceback.format_exc(),
     }
-    return UJSONResponse(
-        data, status_code=500, headers={"Access-Control-Allow-Origin": "*"}
-    )
+    return UJSONResponse(data, status_code=500, headers={"Access-Control-Allow-Origin": "*"})
 
 
 def setup_exception_handlers(app: FastAPI) -> None:
