@@ -24,12 +24,11 @@ class UJSONResponse(BaseUJSONResponse):
     """
 
     def render(self, content: typing.Any) -> bytes:
-        return ujson.dumps(
-            content, ensure_ascii=True, escape_forward_slashes=False
-        ).encode("utf-8")
+        return ujson.dumps(content, ensure_ascii=True, escape_forward_slashes=False).encode("utf-8")
+
 
 class ORJSONResponse(JSONResponse):
     media_type = "application/json"
 
     def render(self, content: typing.Any) -> bytes:
-        return orjson.dumps(content)
\ No newline at end of file
+        return orjson.dumps(content, option=orjson.OPT_SERIALIZE_NUMPY)
