@@ -4,7 +4,7 @@ from io import BytesIO
 from typing import List, Optional, Union, Iterator
 
 from fastapi import UploadFile
-from google.cloud import storage
+from google.cloud.storage import Client as GCPClient
 from google.cloud.exceptions import Conflict, GoogleCloudError, NotFound
 from google.cloud.storage.bucket import Blob, Bucket
 
@@ -29,7 +29,7 @@ class GoogleStorageClient(BaseClient):
     """
 
     __instance = None
-    gcp_storage: storage.Client = None
+    gcp_storage: GCPClient = None
 
     def __new__(cls) -> "GoogleStorageClient":
         """
@@ -59,12 +59,8 @@ class GoogleStorageClient(BaseClient):
             bucket = await self._get_bucket(name)
             return await force_async(bucket.delete)(force=True)
         except ValueError:
-            LOG.warning(
-                f"Too many object in the bucket, unable to delete Bucket: {name}"
-            )
-            raise StorageError(
-                f"Too many object in the bucket, unable to delete Bucket: {name}"
-            )
+            LOG.warning(f"Too many object in the bucket, unable to delete Bucket: {name}")
+            raise StorageError(f"Too many object in the bucket, unable to delete Bucket: {name}")
 
     async def _get_bucket(self, name: str) -> Bucket:
         """
@@ -86,9 +82,7 @@ class GoogleStorageClient(BaseClient):
 
     async def _list_blobs(self, bucket_name, prefix) -> Iterator[Blob]:
         bucket = await self._get_bucket(bucket_name)
-        return await force_async(bucket.list_blobs)(
-            prefix=self.convert_path_in(prefix, bucket_name)
-        )
+        return await force_async(bucket.list_blobs)(prefix=self.convert_path_in(prefix, bucket_name))
 
     @classmethod
     def convert_path_in(cls, path: str, bucket_name) -> str:
@@ -154,9 +148,7 @@ class GoogleStorageClient(BaseClient):
 
         blob = await self._get_blob(bucket_name, file_path)
         try:
-            await force_async(blob.upload_from_string)(
-                string, content_type=content_type
-            )
+            await force_async(blob.upload_from_string)(string, content_type=content_type)
         except GoogleCloudError as err:
             LOG.error(str(err))
             raise StorageError("Something went wrong uploading file {}", file_path)
@@ -166,7 +158,10 @@ class GoogleStorageClient(BaseClient):
         return scidra_file
 
     async def upload_file(
-        self, file: UploadFile, bucket_name: str, parent_path: str = "",
+        self,
+        file: UploadFile,
+        bucket_name: str,
+        parent_path: str = "",
     ) -> File:
         bucket = await self._get_bucket(bucket_name)
         path = self.convert_path_in(parent_path, bucket_name)
@@ -176,14 +171,10 @@ class GoogleStorageClient(BaseClient):
         blob = bucket.blob(path + file.filename)
         try:
             file.file.seek(0)
-            await force_async(blob.upload_from_file)(
-                file.file, content_type=file.content_type
-            )
+            await force_async(blob.upload_from_file)(file.file, content_type=file.content_type)
         except GoogleCloudError as err:
             LOG.error(str(err))
-            raise StorageError(
-                "Something went wrong uploadinf file {}", path + file.filename
-            )
+            raise StorageError("Something went wrong uploadinf file {}", path + file.filename)
         scidra_file = self.blob_to_file(blob, bucket_name)
         if scidra_file is None:
             raise StorageError("A file could not be created from the GCP blob")
@@ -218,15 +209,11 @@ class GoogleStorageClient(BaseClient):
     async def _delete_blob(self, blob: Blob):
         await force_async(blob.delete)()
 
-    async def delete_file(
-        self, bucket_name: str, file_path: str, recursive: bool = False
-    ) -> None:
+    async def delete_file(self, bucket_name: str, file_path: str, recursive: bool = False) -> None:
         try:
             if recursive:
                 blobs = await self._list_blobs(bucket_name, file_path)
-                futures = []
-                for blob in blobs:
-                    futures.append(self._delete_blob(blob))
+                futures = [self._delete_blob(blob) for blob in blobs]
                 if futures:
                     await asyncio.wait(futures)
                 else:
@@ -237,29 +224,19 @@ class GoogleStorageClient(BaseClient):
                 blob = await self._get_blob(bucket_name, file_path)
                 await self._delete_blob(blob)
         except NotFound:
-            raise StorageError(
-                f"Trying to delete a file {bucket_name}/{file_path} that doesn't exist."
-            )
+            raise StorageError(f"Trying to delete a file {bucket_name}/{file_path} that doesn't exist.")
 
-    async def rename_file(
-        self, bucket_name: str, file_path: str, new_file_path: str
-    ) -> None:
+    async def rename_file(self, bucket_name: str, file_path: str, new_file_path: str) -> None:
         bucket = await self._get_bucket(bucket_name)
         blob = bucket.blob(self.convert_path_in(file_path, bucket_name))
         if blob.exists():
-            await force_async(bucket.rename_blob)(
-                blob, self.convert_path_in(new_file_path, bucket_name)
-            )
+            await force_async(bucket.rename_blob)(blob, self.convert_path_in(new_file_path, bucket_name))
         else:
-            raise StorageError(
-                f"Trying to rename a file {bucket_name}/{file_path} that doesn't exist."
-            )
+            raise StorageError(f"Trying to rename a file {bucket_name}/{file_path} that doesn't exist.")
 
         LOG.debug(f"{file_path} renamed to {new_file_path}")
 
-    async def copy_file(
-        self, from_bucket: str, from_path: str, to_bucket: str, to_path: str
-    ) -> None:
+    async def copy_file(self, from_bucket: str, from_path: str, to_bucket: str, to_path: str) -> None:
         bucket = await self._get_bucket(from_bucket)
         blob = bucket.blob(self.convert_path_in(from_path, from_bucket))
         if blob.exists():
@@ -269,14 +246,10 @@ class GoogleStorageClient(BaseClient):
                 self.convert_path_in(to_path, to_bucket),
             )
         else:
-            raise StorageError(
-                f"Trying to copy a file {from_bucket}/{from_path} that doesn't exist."
-            )
+            raise StorageError(f"Trying to copy a file {from_bucket}/{from_path} that doesn't exist.")
         LOG.debug(f"{from_path} copied to {to_path}")
 
-    async def create_temp_file_url(
-        self, bucket: str, path: str, expire_time_hours: int = 3
-    ) -> File:
+    async def create_temp_file_url(self, bucket: str, path: str, expire_time_hours: int = 3) -> File:
         blob = await self._get_blob(bucket, path)
         expire_time = datetime.timedelta(hours=expire_time_hours)
 
@@ -284,9 +257,7 @@ class GoogleStorageClient(BaseClient):
         LOG.info(f"Created url: {url} for file download")
         file_ref = self.blob_to_file(blob, bucket)
         if file_ref is None:
-            raise StorageError(
-                f"Cannot generate a temporary url {bucket}/{path} for a folder."
-            )
+            raise StorageError(f"Cannot generate a temporary url {bucket}/{path} for a folder.")
         file_ref.url = url
         return file_ref
 
@@ -300,7 +271,7 @@ class FirebaseStorageClient(GoogleStorageClient):
 
     __instance = None
     # gcp_storage: storage.Client = None
-    bucket: storage.Bucket = None
+    bucket: Bucket = None
 
     def __new__(cls) -> "FirebaseStorageClient":
         """
@@ -350,10 +321,6 @@ class FirebaseStorageClient(GoogleStorageClient):
 
     async def delete_bucket(self, name: str):
         blobs = list(
-            await force_async(self.bucket.list_blobs)(
-                prefix=get_settings().BUCKET_USER_FOLDER + name + "/"
-            )
-        )
-        await force_async(self.bucket.delete_blobs)(
-            blobs, on_error=self.log_error_not_found
+            await force_async(self.bucket.list_blobs)(prefix=get_settings().BUCKET_USER_FOLDER + name + "/")
         )
+        await force_async(self.bucket.delete_blobs)(blobs, on_error=self.log_error_not_found)
